==> release.12.2.28.1.tgz: cgi-cpn/prontus_regenera_relac.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# SCRIPT.
# -----------
# prontus_regenera_relac.pl

# ---------------------------------------------------------------
# UBICACION.
# -----------
# /cgi-cpn/.

# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# Script encargado de regenerar los archivos relacionados.
# Se usa como alternativa a la regeneración masiva de artículos (que al final realiza
# esta accion) ya que es mas rapido que hacer todo el proceso.
#
# $ARGV[0] : Nombre del Prontus (ej. prontus_noticias)
#
# ---------------------------------------------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use Artic;
use DBI;
use File::Copy;
use HTML::Entities;
use JSON;
use POSIX;
use Time::Local;
use URI::Escape;
use glib_dbi_03;
use glib_fildir_03;
use glib_hrfec_03;
use glib_str_03;
use lib_bd;
use lib_helper;
use lib_maxrunning;
use lib_parser;
use lib_prontus;
use lib_tags;
use lib_tax;
use lib_urlf5;
use lib_utils;
##/libs##

our $DB = undef;
our $counter = 0;

main: {
    lib_utils::setUtf8();

    if (scalar @ARGV < 1) {
        print "Parametros insuficientes Terminando\n";
        exit;
    }

    # Soporta sólo 1 copia andando
    if (lib_maxrunning::maxExcedido(1)) {
        print "Error: Servidor ocupado. Intente otra vez mas tarde.\n";
        exit;
    }

    if ( (! -d "$prontus_varglb::DIR_SERVER") || ($prontus_varglb::DIR_SERVER eq '') )  {
        print "Error: Document root no valido.\n";
        exit;
    }

    $prontus_varglb::PRONTUS_ID = $ARGV[0];
    if ($prontus_varglb::PRONTUS_ID eq '' || !lib_utils::valida_prontus($prontus_varglb::PRONTUS_ID)) {
        print "\nError: Directorio del publicador no es válido.";
        print "\nDebe indicar el nombre del Prontus a procesar (ej: prontus_noticias), como parametro de esta CGI\n";
        exit;
    }

    # Carga variables de configuracion de prontus.
    my $msg_load = lib_utils::load_config_by_id($prontus_varglb::PRONTUS_ID);
    if ($msg_load ne '') {
        print STDERR "Error: $msg_load\n";
        exit;
    }

    # Se conecta a la Base de Datos, si es que no esta conectado
    my ($base, $msg_err_bd) = lib_bd::conectar_prontus_bd();
    if (! ref($base)) {
        print STDERR "ERROR: $msg_err_bd\n";
        exit;
    }

    my %tabla_secc = lib_tax::carga_tabla_seccion($base);
    my %tabla_tem = lib_tax::carga_tabla_temas($base);
    my %tabla_stem = lib_tax::carga_tabla_subtemas($base);

    my %TAXONOMIAS_TO_REGEN;

    # Para las secciones
    foreach my $seccion (keys %tabla_secc) {
        $TAXONOMIAS_TO_REGEN{$seccion . '__'} = '1';
    }

    # Para los temas
    my %hashtemas;
    foreach my $tema (keys %tabla_tem) {
        if($tabla_tem{$tema} =~ /^(.*?)\t\t(.*?)\t\t(.*?)\t\t/) {
            my $seccion = $3;
            $hashtemas{$tema} = $seccion;
            $TAXONOMIAS_TO_REGEN{$seccion . '_'.$tema.'_'} = '1';
        }
    }

    # Para los subtemas
    foreach my $subtema (keys %tabla_stem) {
        if($tabla_stem{$subtema} =~ /^(.*?)\t\t(.*?)\t\t(.*?)\t\t/) {
            my $tema = $3;
            my $seccion = $hashtemas{$tema};
            $TAXONOMIAS_TO_REGEN{$seccion . '_'.$tema.'_'.$subtema} = '1';
        }
    }

    &regen_taxonomia(\%TAXONOMIAS_TO_REGEN, $base);
    print "Los articulos relacionados fueron regenerados\n";
    print "Total de niveles procesados: $counter\n";
}

# --------------------------------------------------------------------
sub regen_taxonomia {
# Regenera art. relacionados
    my ($taxonomia, $base) = @_;

    my ($secc, $tem, $stem);

    lib_tax::set_vars($prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_SITE'},
                        $prontus_varglb::DIR_ARTIC,
                        $prontus_varglb::DIR_PAG,
                        $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'DIR_TEMPLATES'},
                        $prontus_varglb::DIR_TAXONOMIA,
                        $prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'NUM_RELAC_DEFAULT'});

    foreach my $tripleta (keys %$taxonomia) {
        ($secc, $tem, $stem) = split(/_/, $tripleta);
        $secc = '' if($secc eq '0');
        $tem = '' if($tem eq '0');
        $stem = '' if($stem eq '0');
        print "Regenerando tripleta: $tripleta\n";
        lib_tax::generar_relacionados($secc, $tem, $stem, $base, '');

        # Ahora parsea art relacionados para MVs
        foreach my $mv (keys %{$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'MULTIVISTAS'}}) {
            lib_tax::generar_relacionados($secc, $tem, $stem, $base, $mv);
        }

        $counter++;
    }
}

==> release.12.3.1.2.tgz: cgi-cpn/prontus_regenera_relac.pl <==
#!/usr/bin/perl

# ---------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# ---------------------------------------------------------------

# -------------------------------COMENTARIO GLOBAL---------------
# ---------------------------------------------------------------
# SCRIPT.
# -----------
# prontus_regenera_relac.pl

# ---------------------------------------------------------------
# UBICACION.
# -----------
# /cgi-cpn/.

# ---------------------------------------------------------------
# PROPOSITO.
# -----------
# Script encargado de regenerar los archivos relacionados.
# Se usa como alternativa a la regeneración masiva de artículos (que al final realiza
# esta accion) ya que es mas rapido que hacer todo el proceso.
#
# $ARGV[0] : Nombre del Prontus (ej. prontus_noticias)
#
# ---------------------------------------------------------------
use strict;
use utf8;

BEGIN {
    use FindBin qw($Bin);
    my $pathLibsProntus = $Bin;
    unshift(@INC,$pathLibsProntus);
}

##libs##
use lib_stdlog;
lib_stdlog::set_stdlog($0, 51200);
use prontus_varglb;
prontus_varglb::init();

use Artic;
use DBI;
use File::Copy;
use HTML::Entities;
use JSON;
use POSIX;
use Time::Local;
use URI::Escape;
use glib_dbi_03;
use glib_fildir_03;
use glib_hrfec_03;
use glib_str_03;
use lib_bd;
use lib_encodes;
use lib_helper;
use lib_lang;
use lib_maxrunning;
use lib_parser;
use lib_ports;
use lib_prontus;
use lib_tags;
use lib_tax;
use lib_urlf5;
use lib_utils;
##/libs##

our $DB = undef;
our $counter = 0;

main: {
    lib_utils::setUp();

    if (scalar @ARGV < 1) {
        print lib_lang::get_message('global_insufficient_arguments');
        exit;
    }

    # Soporta sólo 1 copia andando
    if (lib_maxrunning::maxExcedido(1)) {
        print lib_lang::get_message('regenera_relac_server_busy');
        exit;
    }

    if ( (! -d "$prontus_varglb::DIR_SERVER") || ($prontus_varglb::DIR_SERVER eq '') )  {
        print lib_lang::get_message('global_docroot_invalid')."\n";
        exit;
    }

    my $prontus_id = $ARGV[0];
    if ($prontus_id eq '' || !lib_utils::valida_prontus($prontus_id)) {
        print "\n".lib_lang::get_message('global_error_invalid_dir');
        print lib_lang::get_message('regenera_global_use');
        exit;
    }

    # Carga variables de configuracion de prontus.
    my $msg_load = lib_utils::load_config_by_id($prontus_id);
    if ($msg_load ne '') {
        print STDERR "$msg_load\n";
        exit;
    }

    # Se conecta a la Base de Datos, si es que no esta conectado
    my ($base, $msg_err_bd) = lib_bd::conectar_prontus_bd();
    if (! ref($base)) {
        print STDERR $msg_err_bd, "\n";
        exit;
    }

    my %tabla_secc = lib_tax::carga_hash_seccion($base);
    my %tabla_tem = lib_tax::carga_hash_temas($base);
    my %tabla_stem = lib_tax::carga_hash_subtemas($base);

    my %TAXONOMIAS_TO_REGEN;
    # Para las secciones
    foreach my $secc_id (keys %tabla_secc) {
        $TAXONOMIAS_TO_REGEN{$secc_id . '__'} = '1';

        foreach my $tema_id (keys %tabla_tem) {
            next unless($secc_id eq $tabla_tem{$tema_id}{'id_padre'});
            $TAXONOMIAS_TO_REGEN{$secc_id . '_'.$tema_id.'_'} = '1';

            foreach my $subtema_id (keys %tabla_stem) {
                next unless($tema_id eq $tabla_stem{$subtema_id}{'id_padre'});
                $TAXONOMIAS_TO_REGEN{$secc_id . '_'.$tema_id.'_'.$subtema_id} = '1';
            }
        }
    }

    &regen_taxonomia(\%TAXONOMIAS_TO_REGEN, $base);
    print lib_lang::get_message('regenera_relac_success');
    print lib_lang::get_interpolated_message('regenera_relac_processed_levels', $counter);
}

# --------------------------------------------------------------------
sub regen_taxonomia {
# Regenera articulos relacionados
    my ($taxonomia, $base) = @_;

    my ($secc, $tem, $stem);
    foreach my $tripleta (keys %$taxonomia) {
        ($secc, $tem, $stem) = split(/_/, $tripleta);
        $secc = '' if($secc eq '0');
        $tem = '' if($tem eq '0');
        $stem = '' if($stem eq '0');
        print lib_lang::get_interpolated_message('regenera_relac_processing_triplet', $tripleta);
        lib_tax::generar_relacionados($secc, $tem, $stem, $base, '');

        # Ahora parsea articulos relacionados para MVs
        foreach my $mv (keys %{$prontus_varglb::CONFIG{$prontus_varglb::PRONTUS_ID}{'MULTIVISTA'}}) {
            lib_tax::generar_relacionados($secc, $tem, $stem, $base, $mv);
        }

        $counter++;
    }
}
